Skip site navigation (1)Skip section navigation (2)
Date:      Wed, 29 Apr 2026 11:40:16 +0000
From:      Andrew Turner <andrew@FreeBSD.org>
To:        src-committers@FreeBSD.org, dev-commits-src-all@FreeBSD.org, dev-commits-src-main@FreeBSD.org
Subject:   git: 2783fb7e7321 - main - arm64: Fix a MTE check
Message-ID:  <69f1ee20.21a9d.7ec8f8ef@gitrepo.freebsd.org>

index | next in thread | raw e-mail

The branch main has been updated by andrew:

URL: https://cgit.FreeBSD.org/src/commit/?id=2783fb7e7321911b4159d7f41d1c80cae40a7552

commit 2783fb7e7321911b4159d7f41d1c80cae40a7552
Author:     Andrew Turner <andrew@FreeBSD.org>
AuthorDate: 2026-04-29 11:34:49 +0000
Commit:     Andrew Turner <andrew@FreeBSD.org>
CommitDate: 2026-04-29 11:39:29 +0000

    arm64: Fix a MTE check
    
    It should be for FEAT_MTE2 as the registers aren't implemented for
    FEAT_MTE.
    
    While here fix the style of the comment explaining the check.
    
    Reported by:    markj
    Fixes:          58de79153622 ("arm64: mte: configure initial state for system registers")
    Sponsored by:   Arm Ltd
---
 sys/arm64/arm64/locore.S | 6 +++---
 1 file changed, 3 insertions(+), 3 deletions(-)

diff --git a/sys/arm64/arm64/locore.S b/sys/arm64/arm64/locore.S
index c86f98da55a8..14300eceb6d5 100644
--- a/sys/arm64/arm64/locore.S
+++ b/sys/arm64/arm64/locore.S
@@ -1065,10 +1065,10 @@ LENTRY(start_mmu)
 	ldr	x2, mair
 
 	/*
 	 * If MTE is supported, configure GCR_EL1 and clear the TFSR registers of
 	 * any pending tag check faults
 	 */
-	CHECK_CPU_FEAT(x3, ID_AA64PFR1, MTE, MTE, 1f)
+	CHECK_CPU_FEAT(x3, ID_AA64PFR1, MTE, MTE2, 1f)
 
 	/* Set GCR_EL1, non-zero tags excluded by default */
 	mov	x3, #(GCR_Exclude_MASK | GCR_RRND)
@@ -1065,10 +1065,10 @@ LENTRY(start_mmu)
 
 	/*
-	 * If MTE is supported, configure GCR_EL1 and clear the TFSR registers of
-	 * any pending tag check faults
+	 * If FEAT_MTE2 is supported, configure GCR_EL1 and clear the TFSR
+	 * registers of any pending tag check faults
 	 */


home | help

Want to link to this message? Use this
URL: <https://mail-archive.FreeBSD.org/cgi/mid.cgi?69f1ee20.21a9d.7ec8f8ef>